Raft v0.1.0 Raft.StateMachine.Echo

Link to this section Summary

Functions

Called when the leader has established that they still have a majority and haven’t been deposed as described in the raft paper section 8. While it is possible to change the state here it is HIGHLY discouraged. Changes during a read will NOT be persisted or replicated to other servers. Any mutations done here will be lost after a crash recovery or when starting a new server

Called whenever there has been a committed write command

Called when the state machine is initialized

Link to this section Functions

Link to this function handle_read(op, state)

Called when the leader has established that they still have a majority and haven’t been deposed as described in the raft paper section 8. While it is possible to change the state here it is HIGHLY discouraged. Changes during a read will NOT be persisted or replicated to other servers. Any mutations done here will be lost after a crash recovery or when starting a new server.

Callback implementation for Raft.StateMachine.handle_read/2.

Link to this function handle_write(op, state)

Called whenever there has been a committed write command.

Callback implementation for Raft.StateMachine.handle_write/2.

Called when the state machine is initialized.

Callback implementation for Raft.StateMachine.init/1.